// ==============================================================
// Script d'enchainement des simulations de gradient stochastique
// ==============================================================

//
// Initialisation du generateur aleatoire
//

   grand('setgen','clcg4');
   seed1 = 11;
   seed2 = 22;
   seed3 = 33;
   seed4 = 44;
   grand('setall',seed1,seed2,seed3,seed4);

//
// Fonction de calcul du spectre d'une matrice
//

   getf('Mmvp.sci')

//
// Fonction d'affichage des resultats
//

   getf('affiche.sci')

   numwin = 0;

//
// Acquisition des caracteristiques du probleme
//

   exec('param-probleme.sce');

//
// Choix du type de simulation a effectuer
//

   l1=list('Simulation unique',1,...
           ['Non','Gradient normal','Gradient moyenne','Les deux']);
   l2=list('Simulation multiple',1,...
           ['Non','Gradient normal','Gradient moyenne','Les deux']);
   l3=list('Evaluation de covariance',1,...
           ['Non','Gradient normal','Gradient moyenne','Les deux']);

//
// Prise en compte des choix effectifs
//

   rep=x_choices('Que voulez-vous faire ?',list(l1,l2,l3));
   choix=(find(rep>1));

//
// Boucle sur les choix retenus
//

   for m = 1:size(choix,'*')

//
//    Type de la simulation
//
//       x = 1 : simulation unique
//       x = 2 : simulation multiple
//       x = 3 : calcul de covariance
//

      x = choix(m);

//
//    Choix du nombre de simulations a effectuer
//

      if x == 2 then
         exec('param-simulation.sce');
      else
         nbsimul = 1;
      end

//
//    Type de l'algorithme
//
//       y = 2 : gradient stochastique normal
//       y = 3 : gradient stochastique moyenne
//       y = 4 : les deux algorithmes precedents
//

      y = rep(choix(m));

//
//    Choix des parametres dans les algorithmes
//

      if y == 2 then
         exec('param-gradient_n.sce');
      elseif y == 3 then
         exec('param-gradient_m.sce');
      elseif y == 4 then
         exec('param-gradient_2.sce');
      else
         abort;
      end
//
//    Resolution par le programme p<x><y> :
//

      exec('p'+string(x)+string(y)+'.sce');

   end

/////////////////////////////
// S.O.W.G - Decembre 2007 //
/////////////////////////////
